/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ISegment as ISegmentCurrent } from "./mergeTreeNodes";
interface ISegment extends ISegmentCurrent {
    attribution?: AttributionCollection<unknown>;
}
export interface SerializedAttributionCollection {
    keys: unknown[];
    posBreakpoints: number[];
    length: number;
}
export declare class AttributionCollection<T> {
    private _length;
    private readonly entries;
    constructor(baseEntry: T, _length: number);
    getAtOffset(offset: number): T;
    get length(): number;
    /**
     * Splits this attribution collection into two with entries for [0, pos) and [pos, length).
     */
    splitAt(pos: number): AttributionCollection<T>;
    append(other: AttributionCollection<T>): void;
    getAll(): {
        offset: number;
        key: T;
    }[];
    clone(): AttributionCollection<T>;
    /**
     * Rehydrates attribution information from its serialized form into the provided iterable of consecutive segments.
     */
    static populateAttributionCollections(segments: Iterable<ISegment>, summary: SerializedAttributionCollection): void;
    /**
     * Condenses attribution information on consecutive segments into a `SerializedAttributionCollection`
     */
    static serializeAttributionCollections(segments: Iterable<ISegment>): SerializedAttributionCollection;
}
export {};
//# sourceMappingURL=attributionCollection.d.ts.map